@@ -8,20 +8,15 @@
 
 #include "iem16_delay.h"
 
+#ifdef DEFDACBLKSIZE
+# define IEM16DEFBLKSIZE DEFDACBLKSIZE
+#else
+# define IEM16DEFBLKSIZE 64
+#endif
 
 
 /* ----------------------------- del16write~ ----------------------------- */
 
-/* routine to check that all del16writes/del16reads/vds have same vecsize */
-void sigdel16write_checkvecsize(t_sigdel16write *x, int vecsize){
-  if (x->x_rsortno != ugen_getsortno())    {
-    x->x_vecsize = vecsize;
-    x->x_rsortno = ugen_getsortno();
-  }
-  else if (vecsize != x->x_vecsize)
-    pd_error(x, "del16read/del16write/vd vector size mismatch");
-}
-
 static void *sigdel16write_new(t_symbol *s, t_floatarg msec){
   int nsamps;
   t_sigdel16write *x = (t_sigdel16write *)pd_new(sigdel16write_class);
@@ -29,7 +24,7 @@ static void *sigdel16write_new(t_symbol *s, t_floatarg msec){
   pd_bind(&x->x_obj.ob_pd, s);
   x->x_sym = s;
   nsamps = msec * sys_getsr() * (float)(0.001f);
-  if (nsamps < 1) nsamps = 1;
+  if (nsamps < IEM16DEFBLKSIZE) nsamps = IEM16DEFBLKSIZE;
   nsamps += ((- nsamps) & (SAMPBLK - 1));
   nsamps += DEFDELVS;
   x->x_cspace.c_n = nsamps;
