@@ -35,7 +35,7 @@ typedef short t_iem16_16bit;
 #define IEM16_SCALE_UP (32767)
 #define IEM16_SCALE_DOWN (1./32767)
 
-#define VERSION "1.1"
+#define VERSION "1.2"
 
 #define UNITBIT32 1572864.  /* 3*2^19; bit 32 has place value 1 */
 
@@ -87,5 +87,18 @@ typedef short t_iem16_16bit;
 # define int32 int  /* a data type that has 32 bits */
 #endif /* system */
 
+#ifndef IEM16_EXTERN
+#ifdef _WIN32
+#ifdef IEM16_INTERNAL
+#define IEM16_EXTERN __declspec(dllexport) extern
+#else
+#define IEM16_EXTERN __declspec(dllimport) extern
+#endif /* IEM16_INTERNAL */
+#else
+#define IEM16_EXTERN extern
+#endif /* _WIN32 */
+#endif /* IEM16_EXTERN */
+
+
 
 #endif
