@@ -12,15 +12,18 @@
 #include "iem16.h"
 #include <string.h>
 
-
 #if defined __WIN32 || defined __WIN32__
+//# define NO_UGEN_SORTNO
+#endif
+
+#ifdef NO_UGEN_SORTNO
 static int ugen_getsortno(void){return 0;}
 #else
 extern int ugen_getsortno(void);
 #endif
 
 
-t_class *sigdel16write_class;
+IEM16_EXTERN t_class *sigdel16write_class;
 
 typedef struct del16writectl{
   int c_n;
@@ -39,7 +42,7 @@ typedef struct _sigdel16write{
 } t_sigdel16write;
 
 
-void sigdel16write_checkvecsize(t_sigdel16write *x, int vecsize);
+IEM16_EXTERN void sigdel16write_checkvecsize(t_sigdel16write *x, int vecsize);
 
 
 # define XTRASAMPS 4
