@@ -47,14 +47,6 @@ static void table16_free(t_table16 *x){
   pd_unbind(&x->x_obj.ob_pd, x->x_tablename);
 }
 
-int table16_getarray16(t_table16*x, int*size,t_iem16_16bit**vec){
-  *size=x->x_size;
-  *vec =x->x_table;
-  return 1;
-}
-void table16_usedindsp(t_table16*x){
-  x->x_usedindsp=1;
-}
 static void table16_resize(t_table16*x, t_float f){
   int i=f;
   int was=x->x_size;
@@ -111,10 +103,13 @@ static void table16_from(t_table16*x, t_symbol*s, int argc, t_atom*argv){
   case 0:break;
   case 4:
     endto    =atom_getfloat(argv+3);
+    /* fallthrough */
   case 3:
     startto  =atom_getfloat(argv+2);
+    /* fallthrough */
   case 2:
     endfrom  =atom_getfloat(argv+1);
+    /* fallthrough */
   case 1:
     startfrom=atom_getfloat(argv);
     break;
