@@ -5,10 +5,11 @@ iem_adaptfilt written by Markus Noisternig & Thomas Musil
 noisternig_AT_iem.at; musil_AT_iem.at
 (c) Institute of Electronic Music and Acoustics, Graz Austria 2018 */
 
-#ifdef NT
-#pragma warning( disable : 4244 )
-#pragma warning( disable : 4305 )
-#endif
+#ifdef _MSC_VER
+#pragma warning( disable : 4305 )  /* uncast const double to float */
+#pragma warning( disable : 4244 )  /* uncast float/int conversion etc. */
+#pragma warning( disable : 4101 )  /* unused automatic variables */
+#endif /* _MSC_VER */
 
 
 #include "m_pd.h"
