@@ -11,9 +11,12 @@ namespace eval ::iem::punish::doublechord:: {
         set lib [string map {" " "\\ "} [file join $::current_plugin_loadpath doublechord]]
         pdsend "pd-_float_template declare -lib $lib"
 
-        pdtk_post "loaded iem::punish::doublechord-plugin\n"
+        ::pdwindow::post "loaded iem::punish::doublechord-plugin\n"
     }
 }
 
-
-::iem::punish::doublechord::register
+if {[ expr $::PD_MAJOR_VERSION.$::PD_MINOR_VERSION < 0.49 ]} {
+    ::iem::punish::doublechord::register
+} {
+    ::pdwindow::debug "disabled iem::punish::doublechord on Pd>=0.49\n"
+}
