@@ -83,6 +83,12 @@ static void canvas_doublechord(t_canvas *x) {
 void doublechord_setup(void)
 {
   t_gotfn dupfun = 0;
+  int major, minor, bugfix;
+  sys_getversion(&major, &minor, &bugfix);
+  if((major>0 || minor >= 49)) {
+    error("double-chord built into Pd>=0.49, not enabling iem::punish::doublechord");
+    return;
+  }
   if(NULL==canvas_class) {
     verbose(10, "double-chord detected class_new() @ %p", class_new);
     return;
