@@ -72,7 +72,7 @@ namespace eval ::iem::punish::patcherize:: {
         set lib [string map {" " "\\ "} [file join $::current_plugin_loadpath patcherize]]
         pdsend "pd-_float_template declare -lib $lib"
 
-        pdtk_post "loaded iem::punish::patcherize-plugin\n"
+        ::pdwindow::post "loaded iem::punish::patcherize-plugin\n"
     }
 }
 
