@@ -267,7 +267,7 @@ static unsigned int object_getmaxdollar(t_object*obj, unsigned int intermediate)
       while(*s){
         if('$' == *s) {
           char*endptr=0;
-          long int v=strtol(s+1, &endptr, 10);
+          unsigned int v=(unsigned int)strtol(s+1, &endptr, 10);
           s=endptr;
           if(v>dollarg)dollarg=v;
         } else
@@ -694,7 +694,10 @@ static void canvas_patcherize(t_glist*cnv, t_symbol*s) {
 
 void patcherize_setup(void)
 {
-  if(NULL==canvas_class)return;
+  if(NULL==canvas_class) {
+    verbose(10, "patcherize detected class_new() @ %p", class_new);
+    return;
+  }
   //iemguts_boilerplate("patcherize - turn objects into a subpatch", 0);
   post("patcherize - turn objects into a subpatch");
 
